# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.1.1] - 2024-11-23

- Fix path resolution for font registration.

## [1.1.0] - 2024-11-23

- Fix dependency conflicts with `MoviePy 2.0.0`

## [1.0.8 - 1.0.9] - 2024-09-16

- Fix banner display in `README.md` on `PyPI`.

## [1.0.7] - 2024-09-16

- Add `version` command to the CLI.

## [1.0.6] - 2024-09-15

- Force `MoviePy` and `ImageIO` to use the `ffmpeg` binary from the `PATH` environment variable.

## [1.0.5] - 2024-09-06

- Fix reexecution with admin privileges.

## [1.0.2 - 1.0.4] - 2024-09-05/2024-09-06

- Fix admin privileges.
- Separate `register_font` admin logic from the main package.
- Improve CLI

## [1.0.1] - 2024-09-05

Fix admin privileges for the `Linux` users.

## [1.0.0] - 2024-09-05

Initial release of Captametropolis! 🎉